@@ -868,8 +868,10 @@ bool BookWindow::Load(QString filename)
     }
 
     QVariant var = settings.value("player");
-    if (var.isValid())
+    if (var.isValid()){
         m_Player = new Player(var.value<Player>());
+        m_Player->Dump();
+    }
 
     int index = settings.beginReadArray("items");
     for (int i=0; i<index; i++){
