@@ -289,7 +289,8 @@ Weapon* Book::ParseWeapon(Section* section, QXmlStreamReader* reader)
     QXmlStreamAttributes attrs = reader->attributes();
     w->Name = attrs.value("name").toString();
     w->Description = attrs.value("description").toString();
-    w->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
+    if (attrs.hasAttribute("canbeequipped"))
+        w->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     w->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
 
     QString tclass = attrs.value("class").toString();
@@ -318,7 +319,8 @@ Item* Book::ParseItem(Section* section, QXmlStreamReader* reader)
     QXmlStreamAttributes attrs = reader->attributes();
     i->Name = attrs.value("name").toString();
     i->Description = attrs.value("description").toString();
-    i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
+    if (attrs.hasAttribute("canbeequipped"))
+        i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     i->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
     i->SetIsMeal(attrs.value("ismeal").toString().toInt() == 1);
     i->SetIsArrow(attrs.value("isarrow").toString().toInt() == 1);
@@ -350,7 +352,8 @@ ShopItem* Book::ParseShopItem(Section* section, QXmlStreamReader* reader)
     QXmlStreamAttributes attrs = reader->attributes();
     i->Name = attrs.value("name").toString();
     i->Description = attrs.value("description").toString();
-    i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
+    if (attrs.hasAttribute("canbeequipped"))
+        i->SetCanBeEquipped(attrs.value("canbeequipped").toString().toInt() == 1);
     i->SetIsSpecial(attrs.value("special").toString().toInt() == 1);
     i->SetIsMeal(attrs.value("ismeal").toString().toInt() == 1);
     i->SetIsBackpack(attrs.value("isbackpack").toString().toInt() == 1);
@@ -572,3 +575,10 @@ bool Book::Save(QString filename)
     FileName = filename;
     return true;
 }
+
+QString Book::GetAttribute(QXmlStreamAttributes attrs, QString name, QString defaultValue)
+{
+    if (attrs.hasAttribute(name))
+        return attrs.value(name).toString();
+    return defaultValue;
+}
