@@ -35,7 +35,7 @@ public:
     QString Name;
     QString Description;
 
-    bool IsUsable() { return GetIsMeal() || GetEnduranceRestore(); }
+    bool IsUsable() { return GetIsMeal() || GetEnduranceRestore() || GetCombatskillDelta(); }
     void Use(QScriptEngine* engine, QScriptValue* functions);
 
 public slots:
