@@ -1,4 +1,5 @@
 #include "player.h"
+#include <QDebug>
 
 Player::Player(QObject *parent) :
     QObject(parent)
@@ -29,6 +30,7 @@ Player::Player(const Player& player) :
     m_CanHunt = player.m_CanHunt;
 
     DeathsCount = player.DeathsCount;
+    Properties = QHash<QString, QString>(player.Properties);
 }
 
 QList<Weapon*> Player::Weapons()
@@ -640,3 +642,11 @@ void Player::ClearProperties()
 {
     Properties.clear();
 }
+
+void Player::Dump()
+{
+    qDebug() << "Properties:";
+    foreach(QString key, Properties.keys()){
+        qDebug() << key << ":" << Properties[key];
+    }
+}
