@@ -240,7 +240,7 @@ void FightWindow::Evaluate(int number)
 
     if (playerDamage){
         m_Player->Endurance -= m_PlayerDamage;
-        m_PlayerPointsLost += m_EnemyDamage;
+        m_PlayerPointsLost += m_PlayerDamage;
         if (m_Player->IsDead()){
             message.append("You were <b>killed</b>");
             ui->lblDice->setText("<font color=\"red\">You lost!</font>");
